# -*- coding: utf-8 -*-

import imp
import json
import re
import demjson3
import jsonpath

class UtilJson(object):
    "container->ip@[0]"
    "container->ip@[1]->tel@[1]"
    "container->ip@[1]"
    "container->ip@[*]"

    "data->machines@[0]->ip@[$(cluster=hz)]"
    

    num =0
    # TODO delete 
    def get_element_by_key(self, key, src_dict):
        """ return list element, or a element """
        if isinstance(src_dict, list):
            list_key = key.split("@")
            if len(list_key) < 2:
                raise  DogException("src_dict is list, but key used a error type,just ip@[1] is supported.")
            elif len(list_key) == 2:
                index = list_key[1][1:-1]
                """
                @[*]
                @[0]
                @[1]
                @[$(cluster=hz)]
                
                """
                # print(index)
                if index == "*" :
                    element_list = []
                    for element in src_dict:
                        element_list.append(self.__element(list_key[0],element))
                    return element_list
                else :
                    fit_index = re.search(r'^\[[0-9]+\]$', list_key[1])
                    if fit_index  :
                        # print("fit_index finded", list_key[1])
                        # TODO index may big then len(src_dict)
                        return self.__element(list_key[0],src_dict[int(index)])
                    
                    fit_attribute = re.search('^\[\$\(.*?\)\]$', list_key[1])
                    if fit_attribute:
                        element_list = []
                        attr = index[2:-1]
                        # print("fit_attribute", attr)
                        attr_name_val = attr.split("=")
                        for element in src_dict:
                            # print(self.__element(attr_name_val[0],element))
                            # print("".join(attr_name_val[1:]))
                            if self.__element(attr_name_val[0],element) == "".join(attr_name_val[1:]):
                                element_list.append(self.__element(list_key[0],element))
                        return element_list
        else:
            # print("<<< ",key)
            return self.__element(key,src_dict)
        # print("____________________________________________________________")
        return None
    # TODO delete 
    def get_element_by_keypath(self, keypath, src_dict):
        # print("get_element_by_keypath", keypath, src_dict)
        # print(keypath)
        keypath_list = keypath.split("->")
        # print(len(keypath_list))
        if len(keypath_list)>1:
            first_key = keypath_list[0]
            sub_keypath = "->".join(keypath_list[1:])
            sub_src_dict = self.get_element_by_key(first_key, src_dict)

            # if isinstance(sub_src_dict, list):
            #     for element in sub_src_dict:
            #         return self.get_element_by_keypath(sub_keypath,element)
            #         pass
            #     pass
            return self.get_element_by_keypath(sub_keypath,sub_src_dict)

        elif len(keypath_list)>0:
            first_keypath = keypath_list[0]
            # print(first_keypath)
            sub_element_or_list = self.get_element_by_key(first_keypath, src_dict)
            return sub_element_or_list
        else:
            raise DogException("get_element_by_keypath： keypath exception.")




    def __element(self, key, src_dict):
        element = None
        # if not src_dict:
        #     raise Exception("'NoneType' object has no attribute 'keys'")
        if key in src_dict.keys():
            element = src_dict[key]
            pass
        # print(">>> ", key," __ ", src_dict)
        # print(type(src_dict))
        
        # print(element)
        return element
    
    def find_elements_by_key(self, key, src_dict_list):
            list_key = key.split("@")
            if len(list_key) < 2:
                raise  DogException("src_dict is list, but key used a error type,just ip@[1] is supported.")
            elif len(list_key) == 2:
                index = list_key[1][1:-1]
                """
                @[*]
                @[0]
                @[1]
                @[$(cluster=hz)]
                
                """
                # print(index)
                if index == "*" :
                    element_list = []
                    for element in src_dict_list:
                        element_list.append(self.__element(list_key[0],element))
                    return element_list
                else :
                    fit_index = re.search(r'^\[[0-9]+\]$', list_key[1])
                    # print("TODO find","fit_index", list_key[1])
                    if fit_index  :
                        # print("fit_index finded", list_key[1])
                        # TODO index may big then len(src_dict)
                        return self.__element(list_key[0],src_dict_list[int(index)])
                    
                    fit_attribute = re.search('^\[\$\(.*?\)\]$', list_key[1])
                    if fit_attribute:
                        element_list = []
                        attr = index[2:-1]
                        # print("fit_attribute", attr)
                        attr_name_val = attr.split("=")
                        for element in src_dict_list:
                            print(self.__element(attr_name_val[0],element))
                            print("".join(attr_name_val[1:]))
                            
                            if self.__element(attr_name_val[0],element) == "".join(attr_name_val[1:]):
                                element_list.append(self.__element(list_key[0],element))
                        return element_list
    
    def find_element_by_keypath(self, keypath, src_dict):
        keypath_list = keypath.split("->")
        first_key = keypath_list[0]
        if isinstance(src_dict, list):
            sub_src_dict_element_list = self.find_elements_by_key(first_key, src_dict)
            if not sub_src_dict_element_list  or  sub_src_dict_element_list == "null" :
                return sub_src_dict_element_list
            if len(keypath_list)>1:
                sub_keypath = "->".join(keypath_list[1:])
                res_list = []
                for sub_src_dict_element in sub_src_dict_element_list:
                    if not sub_src_dict_element:
                        element = None
                    else:
                        element = self.find_element_by_keypath(sub_keypath, sub_src_dict_element) 
                        res_list.append(element) 
                return res_list
            else:
                return sub_src_dict_element_list
        else:
            sub_src_dict_element = self.__element(first_key, src_dict) 
            if not sub_src_dict_element or  sub_src_dict_element == "null" :
                return sub_src_dict_element
            if len(keypath_list)>1:
                sub_keypath = "->".join(keypath_list[1:])
                return self.find_element_by_keypath(sub_keypath,sub_src_dict_element) 
            else:
                return sub_src_dict_element

    def json_loads(self, src_json_str):
        # "{'aaa':123,'bbb':'1:12'}"
        ds = demjson3.decode(src_json_str)
        return ds

    def json_dumps(self, src_json_dict):
        return demjson3.encode(src_json_dict)

    def json_pretty_printed(self, src):
        src_json_dict_tmp = src
        if isinstance(src, str) :
            src_json_dict_tmp = self.json_loads(src)
        return json.dumps(src_json_dict_tmp ,sort_keys=True, indent=4,ensure_ascii=False)

    def json_compress_str(self, src_json_dict):
        return json.dumps(src_json_dict)
    pass

    def jsonpath(self, dt, expr):
        # "$.content[*].value[0]"
        ret = jsonpath.jsonpath(dt, expr)
        return ret

class DogException(Exception):

    pass

util_json = UtilJson()

# src_dict_str="{\"id\":894,\"package\":{\"id\":117,\"name\":\"docker.cloud.new.0.5-2(微应用大内存)\",\"cpu\":\"0.5\",\"cpu_extend_max\":\"2\",\"memory\":\"6144Mi\",\"memory_extend_max\":\"6144Mi\",\"network\":\"1\"},\"container\":[{\"id\":786066,\"package\":{\"id\":117,\"name\":\"docker.cloud.new.0.5-2(微应用大内存)\",\"cpu\":\"0.5\",\"cpu_extend_max\":\"2\",\"memory\":\"6144Mi\",\"memory_extend_max\":\"6144Mi\",\"network\":\"1\"},\"location\":{\"id\":1,\"name\":\"阿里云-华东一区\"},\"key\":786066,\"tag_fmt\":[],\"name\":\"mall-hz-565f5c67bb-h6j42\",\"instance_id\":null,\"ip\":\"172.22.34.146\",\"host_ip\":\"10.111.11.127\",\"node\":\"\",\"pip\":null,\"cpu\":0,\"memory\":0,\"disk\":0,\"zone\":\"cn-hangzhou-h\",\"status\":\"Running\",\"description\":null,\"category\":\"cloud-docker\",\"docker_flag\":0,\"cost\":0.01,\"resource_version\":0,\"restart_count\":0,\"ready\":true,\"image\":\"harbor.ymmoa.com/app/mall:war-master-jdk8-20200311_163914\",\"reason\":\"\",\"lane\":\"default\",\"share\":0,\"age\":\"25天49分\",\"channel_sign\":\"\",\"create_time\":\"2020-03-26T13:06:03Z\",\"expires_time\":null,\"jmap_status\":null,\"jmap_package_url\":null,\"tag\":[]},{\"id\":789292,\"package\":{\"id\":117,\"name\":\"docker.cloud.new.0.5-2(微应用大内存)\",\"cpu\":\"0.5\",\"cpu_extend_max\":\"2\",\"memory\":\"6144Mi\",\"memory_extend_max\":\"6144Mi\",\"network\":\"1\"},\"location\":{\"id\":1,\"name\":\"阿里云-华东一区\"},\"key\":789292,\"tag_fmt\":[],\"name\":\"mall-hz-565f5c67bb-7gqdz\",\"instance_id\":null,\"ip\":\"172.22.16.80\",\"host_ip\":\"10.111.11.89\",\"node\":\"\",\"pip\":null,\"cpu\":0,\"memory\":0,\"disk\":0,\"zone\":\"cn-hangzhou-h\",\"status\":\"Running\",\"description\":null,\"category\":\"cloud-docker\",\"docker_flag\":0,\"cost\":0.01,\"resource_version\":0,\"restart_count\":0,\"ready\":true,\"image\":\"harbor.ymmoa.com/app/mall:war-master-jdk8-20200311_163914\",\"reason\":\"\",\"lane\":\"default\",\"share\":0,\"age\":\"24天2时17分\",\"channel_sign\":\"\",\"create_time\":\"2020-03-27T11:38:46Z\",\"expires_time\":null,\"jmap_status\":null,\"jmap_package_url\":null,\"tag\":[]},{\"id\":851008,\"package\":{\"id\":117,\"name\":\"docker.cloud.new.0.5-2(微应用大内存)\",\"cpu\":\"0.5\",\"cpu_extend_max\":\"2\",\"memory\":\"6144Mi\",\"memory_extend_max\":\"6144Mi\",\"network\":\"1\"},\"location\":{\"id\":1,\"name\":\"阿里云-华东一区\"},\"key\":851008,\"tag_fmt\":[],\"name\":\"mall-gpre-7b877857b9-26b28\",\"instance_id\":null,\"ip\":\"172.22.123.79\",\"host_ip\":\"10.111.11.7\",\"node\":\"\",\"pip\":null,\"cpu\":0,\"memory\":0,\"disk\":0,\"zone\":\"cn-hangzhou-h\",\"status\":\"Running\",\"description\":null,\"category\":\"cloud-docker\",\"docker_flag\":0,\"cost\":0.01,\"resource_version\":0,\"restart_count\":0,\"ready\":true,\"image\":\"harbor.ymmoa.com/app/mall:war-master-jdk8-20200420_173025\",\"reason\":\"\",\"lane\":\"default\",\"share\":0,\"age\":\"2时59分\",\"channel_sign\":\"gpre\",\"create_time\":\"2020-04-20T10:56:40Z\",\"expires_time\":null,\"jmap_status\":null,\"jmap_package_url\":null,\"tag\":[]},{\"id\":851009,\"package\":{\"id\":117,\"name\":\"docker.cloud.new.0.5-2(微应用大内存)\",\"cpu\":\"0.5\",\"cpu_extend_max\":\"2\",\"memory\":\"6144Mi\",\"memory_extend_max\":\"6144Mi\",\"network\":\"1\"},\"location\":{\"id\":1,\"name\":\"阿里云-华东一区\"},\"key\":851009,\"tag_fmt\":[],\"name\":\"mall-gpre-7b877857b9-9wj8f\",\"instance_id\":null,\"ip\":\"172.22.6.190\",\"host_ip\":\"10.111.11.130\",\"node\":\"\",\"pip\":null,\"cpu\":0,\"memory\":0,\"disk\":0,\"zone\":\"cn-hangzhou-h\",\"status\":\"Running\",\"description\":null,\"category\":\"cloud-docker\",\"docker_flag\":0,\"cost\":0.01,\"resource_version\":0,\"restart_count\":0,\"ready\":true,\"image\":\"harbor.ymmoa.com/app/mall:war-master-jdk8-20200420_173025\",\"reason\":\"\",\"lane\":\"default\",\"share\":0,\"age\":\"2时43分\",\"channel_sign\":\"gpre\",\"create_time\":\"2020-04-20T11:12:33Z\",\"expires_time\":null,\"jmap_status\":null,\"jmap_package_url\":null,\"tag\":[]}],\"yaml\":[],\"auto\":{\"id\":264,\"min_replicas\":2,\"max_replicas\":4,\"target_cpu_percentage\":100,\"current_replicas\":2,\"current_cpu_percentage\":300,\"user\":\"10304\",\"username\":\"李波\",\"ctime\":\"2018-11-21T03:56:58.350657Z\",\"utime\":\"2019-06-17T09:48:57.105017Z\"},\"deployment\":\"mall-hz\",\"project_name\":\"mall\",\"generate_name\":\"mall-hz-7c9d588c84-9wsw8\",\"namespace\":\"prod\",\"lane\":\"default\",\"env\":\"hz\",\"full_path\":\"com.ymm.bop.mall.mall-app.hz\",\"replicas\":2,\"description\":null,\"user\":\"9999\",\"username\":\"张小伟\",\"status\":\"running\",\"unavailableReplicas\":0,\"label\":\"\",\"ctime\":\"2018-09-26T09:21:03.777588Z\",\"utime\":\"2020-04-16T13:56:02.828817Z\"}"
# src_dict=json.loads(src_dict_str)
# util_json = UtilJson()
# keypath="container->ip@[0]"
# dist = util_json.get_element_by_keypath(keypath, src_dict)
# print(dist)







# -*-coding=utf-8 -*-
__author__  = "8034.com"
__date__    = "2020-05-28"

import os
import subprocess

class SYSCMD(object):

    def cmd(self, command):
        print("EXCE COMMAND:\t" + command)
        code = os.system(command)
        print("RETRUN:\t" , code)
        pass


    def os_popen(self, command):
        print("EXCE COMMAND:\t" + command)
        with os.popen(command, 'r') as f:
            text = f.read()
        print("RETRUN:\t" , text)
        return text

    def proc_call(self, command):
        print("EXCE COMMAND:\t" + command)
        code = subprocess.call(command)
        print("RETRUN:\t" , code)
        return code 

    def proc_popen(self, command):
        print("EXCE COMMAND:\t" + command)

        proc = subprocess.Popen(command,shell=True,stdout=subprocess.PIPE)
        # proc.pid    # 查看子进程ID
        # proc.stdout # 查看子进程 标准输出
        # proc.poll() # 查看子进程状态
        # proc.wait() # 等待子进程结束
        # proc.communicate(input=None)  # 向子进程发送文字输入
        # proc.send_signal(subprocess.signal.CTRL_C_EVENT) # 向子进程发送信号
        # proc.terminate()              # 停止子进程=发送SIGTERM信号
        # proc.kill()       # 杀死子进程=发送SIGKILL信号
        # proc.stdin        # 查看子进程 标准输入
        # proc.stderr       # 查看子进程 标准错误
        # proc.returncode   # 子程序的返回值

        print("RETRUN:\t" , proc.returncode)
        return proc 
    pass

sys_cmd = SYSCMD()

proc = sys_cmd.proc_popen("echo %PATH%") 
print(proc.pid)
print(proc.stdout.readlines())
print(proc.poll)

# sys_cmd.cmd("echo %PATH%")


# -*- coding: utf-8 -*-


import rsa

@staticmethod
def create_rsa_keys(code='nooneknows'):
    # 生成 2048 位的 RSA 密钥
    key = RSA.generate(2048)
    encrypted_key = key.exportKey(passphrase=code, pkcs=8, protection="scryptAndAES128-CBC")
    # 生成私钥
    with open('private_rsa_key.bin', 'wb') as f:
        f.write(encrypted_key)
    # 生成公钥
    with open('rsa_public.pem', 'wb') as f:
        f.write(key.publickey().exportKey())


@staticmethod
def file_encryption(file_name, public_key):
    """
    文件加密
    :param file_name: 文件路径名
    :param public_key: 公钥
    :return:
    """
    # 二进制只读打开文件，读取文件数据
    with open(file_name, 'rb') as f:
        data = f.read()
    file_name_new = file_name + '.rsa'
    with open(file_name_new, 'wb') as out_file:
        # 收件人秘钥 - 公钥
        recipient_key = RSA.import_key(open(public_key).read())
        # 一个 16 字节的会话密钥
        session_key = get_random_bytes(16)
        # Encrypt the session key with the public RSA key
        cipher_rsa = PKCS1_OAEP.new(recipient_key)
        out_file.write(cipher_rsa.encrypt(session_key))
        # Encrypt the data with the AES session key
        cipher_aes = AES.new(session_key, AES.MODE_EAX)

        cipher_text, tag = cipher_aes.encrypt_and_digest(data)
        out_file.write(cipher_aes.nonce)
        out_file.write(tag)
        out_file.write(cipher_text)
    return file_name_new


@staticmethod
def file_decryption(file_name, code, private_key):
    """
    文件解密
    :param file_name: 文件路径名
    :param code: 密码
    :param private_key: 私钥
    :return: 
    """
    with open(file_name, 'rb') as f_in:
        # 导入私钥
        private_key = RSA.import_key(open(private_key).read(), passphrase=code)
        # 会话密钥, 随机数, 消息认证码, 机密的数据
        enc_session_key, nonce, tag, cipher_text = [f_in.read(x) for x in (private_key.size_in_bytes(), 16, 16, -1)]
        cipher_rsa = PKCS1_OAEP.new(private_key)
        session_key = cipher_rsa.decrypt(enc_session_key)
        cipher_aes = AES.new(session_key, AES.MODE_EAX, nonce)
        # 解密
        data = cipher_aes.decrypt_and_verify(cipher_text, tag)
    # 文件重命名
    out_file_name = file_name.replace('.rsa', '')
    with open(out_file_name, 'wb') as f_out:
        f_out.write(data)
    return out_file_name


# -*- coding: utf-8 -*-


class ContentTypeEmnu(object):
    APPLICATION_XWWWFORMURLENCODED = "application/x-www-form-urlencoded"
    TEXT_PLAIN = "text/plain" 
    APPLICATION_JSON = "application/json" 
    APPLICATION_XML = "application/xml" 
    TEXT_XML = "text/xml" 
    TEXT_HTML = "text/html" 
    APPLICATION_JAVASCRIPT = "application/javascript" 
    pass

class HeaderEmnu(object):
    CONTENT_TYPE = "Content-Type"
    authorization = "authorization"
    COOKIES="Cookie"
    HOST="Host"
    ACCEPT="Accept"
    REFERER="Referer"
    pass

    
class methodEmnu(object):
    POST = "POST"
    GET = "GET"
    pass


# -*- coding: utf-8 -*-

import requests
import json
import time

class HEADER(object):
    __headers = {}

    def init(self, header):
        if not self.__headers:
            self.__headers = header
        return self

    def add(self, key, val):
        self.__headers[key] = val
        return self.__value()

    def delete(self, name):
        self.__headers.pop(name)
        return self.__value()

    def clear(self):
        self.__headers = None
        return self.__value()

    def __value(self):
        return self.to_string(self.__headers)
     
    def to_string(self, json_dict):
        return json.dumps(json_dict)

    def update(self, json):
        for key, val in json:
            self.__headers[key]=val
        return self.__value()

    def get_headers(self):
        return self.__headers
    pass

class COOKIES(object):
    """ 初始化 key_vals_str """
    """ 维护 key_vals_json """
    """ 呈现使用 key_vals_str """

    key_vals_str=None
    key_vals_json={}

    def length(self):
        return len(self.key_vals_json)

    def init(self, cookie):
        if not self.key_vals_str:
            self.key_vals_str = cookie
        self.key_vals_json = self.to_json(self.key_vals_str)
        self.__value()
        return self

    def init_json(self, key_vals_json):
        self.key_vals_json = key_vals_json
        self.__value()
        return self

    def add(self, key, val):
        key = key.strip()
        self.key_vals_json[key]=val
        return self.__value()

    def delete(self, name):
        self.key_vals_json.pop(name)
        return self.__value()

    def clear(self):
        self.key_vals_json = None
        return self.__value()

    def __value(self):
        if None ==self.key_vals_json:
            self.key_vals_str =""
            return self.key_vals_str
        self.key_vals_str = self.to_string(self.key_vals_json)
        return self.key_vals_str
     
    def to_string(self, key_vals_json_tmp):
        tmp_string = ""
        if not json:
            return tmp_string
        for key, val in key_vals_json_tmp.items():
            tmp_string = tmp_string + key + "=" + val +";"
        return tmp_string

    def to_json(self, key_vals_str_tmp):
        key_vals_json_tmp={}
        key_val_list = key_vals_str_tmp.split(";")
        for key_val in key_val_list:
            co_list = key_val.split("=")
            if len(co_list) >1:
                key_tmp = co_list[0].strip()
                val_tmp = co_list[1].strip()
                if key_tmp: 
                    key_vals_json_tmp[key_tmp]=val_tmp
            elif len(co_list) >0:
                key_tmp = co_list[0].strip()
                if key_tmp: 
                    key_vals_json_tmp[key_tmp]=""
        return key_vals_json_tmp

    def update_json(self, key_vals_json_new):
        for key, val in key_vals_json_new:
            key = key.strip()
            self.key_vals_json[key]=val
        return self.__value()

    def update_str(self, key_vals_str_new):
        key_vals_json_new_tmp = self.to_json(key_vals_str_new)
        for key, val in key_vals_json_new_tmp.items():
            self.key_vals_json[key]=val
        return self.__value()

    def cookie(self):
        return self.__value()

    def cookie_show_json(self):
        return self.to_json(self.key_vals_str)

class ParamTool(object):
    __params = {} # inner data dict
    __params_dict = {} # dict: {"name":"xiaoming","age":10}
    __params_dictstr = "" # dict_string: """ {"name":"xiaoming","age":10} """
    __params_keystr = "" # key_value_string: """ {"name":"xiaoming","age":10} """

    def init_dict(self, p_dict):
        params = p_dict
        if isinstance(params, dict):
            self.__params_dict = params
            self.__params = self.__params_dict
            self.sync()
            return self
        raise Exception("[ERROR] init param type is not dict, e.g.: {\"name\":\"xiaoming\",\"age\":10}") 

    def init_dictstr(self, p_dictstr):
        params = p_dictstr.strip()
        if isinstance(params, str):
            if params.startswith("{") and params.endswith("}"):
                self.__params_dictstr = params
                self.__params = self.from_dictstr(params) 
                self.sync()
                return self
        raise Exception("[ERROR] init param type is not dict, e.g.: \"\"\"{\"name\":\"xiaoming\",\"age\":10}\"\"\"") 

    def init_keystr(self, p_keystr):
        params = p_keystr.strip()
        self.__params_keystr = params
        self.__params = self.from_keystr(params) 
        self.sync()
        return self

    def sync(self):
        self.__params_dict = self.to_dict()
        self.__params_dictstr = self.to_dictstr()
        self.__params_keystr = self.to_keystr()
        return self

    def to_dict(self):
        return self.__params
    def to_dictstr(self):
        return json.dumps(self.__params)
    def to_keystr(self):
        tmp_str = ""
        # print(self.__params)
        for key, val in self.__params.items():
            # print( key, val)
            if val is None : val = "null"
            val = str(val)
            tmp_str = tmp_str + key + "=" + val
            tmp_str = tmp_str + "&"
        if tmp_str.endswith("&"):
            tmp_str = tmp_str[:-1]
        return tmp_str

    def from_dictstr(self, p_dictstr):
        json_dict= {}
        tmp_dict = json.loads(p_dictstr)
        json_dict = tmp_dict
        return json_dict 
    def from_keystr(self, p_keystr):
        json_dict= {}
        params_list = p_keystr.split("&")
        for key_val in params_list:
            param_list = key_val.split("=")
            key = param_list[0]
            val = "" if len(param_list)<2 else param_list[1]
            json_dict[key] = val
        return json_dict        

    # self.sync()
    def add(self, key, val,sync=False):
        self.__params[key] = val
        if sync: self.sync()
        return self

    def update(self, p_dict,sync=False):
        for key, val in p_dict:
            self.__params[key]=val
        if sync: self.sync()
        return self

    def delete(self, key,sync=False):
        self.__params.pop(name)
        if sync: self.sync()
        return self

    def clear(self):
        self.__params = {}
        self.__params_dict = {}
        self.__params_dictstr = ""
        self.__params_keystr = ""
        return self

    def log(self):
        print(">> [INFO] {}".format( self.get_dictstr() ))
        return self

    def get_dict(self):
        return self.__params_dict

    def get_dictstr(self):
        return self.__params_dictstr

    def get_keystr(self):
        return self.__params_keystr
    pass

class WBrowser(object):
 
    __url = ""
    __data = None  # post请求数据类型， 
    __json = None  # post请求json类型， 输入类型dict
    __headers_dict = None  # 类型字典 dict
    __method = 'get'
    __params = None # url后面的参数, 

    __response = None
    __trans_time = 0
    __transaction_point_start = None


    def transaction(self):
        _transaction_point_end = time.time()
        if not self.__transaction_point_start:
            self.__transaction_point_start = time.time()
        self.__trans_time = _transaction_point_end - self.__transaction_point_start
        return self

    def transaction_point(self):
        self.__transaction_point_start = time.time()
        return self

    def show_trans_time(self):
        return self.__trans_time

        
    def __init__(self,headers=None):
        self.__headers_dict = headers
        pass

    def url(self, url):
        self.__url = url
        return self

    def method(self, method):
        self.__method = method
        return self

    def header(self, header_dict):
        self.__headers_dict = header_dict
        return self

    def get_header(self):
        return self.__headers_dict

    def body_json(self, json):
        self.__json = json
        return self

    def body_data(self, data):
        self.__data = data
        return self

    def body_params(self, params):
        self.__params = params
        return self

    def __visit(self):
        self.transaction_point()
        method_name = self.__method.lower()
        if self.__params: self.__url = "{}?{}".format(self.__url, self.__params) 
        # 注意request的 **kwargs可用于扩展
        if('get' == method_name):
            print(">> {} {}".format(self.__method, self.__url ))
            response = requests.get(self.__url, headers=self.__headers_dict)
            pass

        if('post' == method_name):
            # 
            print(">> {} {} {} {}".format(self.__method, self.__url,  self.__data,  self.__json ))
            
            response = requests.post(self.__url, 
            data=self.__data, 
            json=self.__json, 
            headers=self.__headers_dict)
            pass
        self.__response = response
        
        self.transaction()
        print("[INFO] visit at: {}\t[ Status:{}]".format(  time.strftime("%Y-%m-%d %X",time.localtime()), self.__response.status_code  ))
        return self.__response

    def visit(self):
        """
        :: request
        request.post(url, data=None, json=None, file=None, **kwargs):
        request.get(url, params=None, **kwargs):

        :: response
        response.status_code
        response.text
        response.encoding
        response.apparent_encoding
        response.content
        response.headers
        """

        return self.__visit()
    pass

browser = WBrowser()



#!/usr/bin/python 
# -*- coding: utf-8 -*-

from enum import Enum
from xmlrpc.client import boolean
class RetStatus(Enum):
    PASSED = 1
    FAILED = 2
    ERROR = 9
    SKIPPED = 0

    pass


from functools import wraps

import traceback

__runwell =True
__run_msg = ""

def println(iscontinue=True):
    def decorated(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            __runwell = True
            result = None
            try:
                result = func(*args, **kwargs)
            except Exception as e:
                traceback.print_exc()
                __runwell =False
                __run_msg = e
                pass
            finally:
                print("{}<Func> execute: {}{}".format(
                                                    func.__name__, 
                                                    result if __runwell else False, 
                                                    ".\t Exception happend: {}".format(__run_msg) if not __runwell else "" ))
                if not iscontinue: exit(0)
            return result
        return wrapper
    return decorated

""" { "suite" : ["测试方法": {"url":"https://XXXX", "data": "json_str", "result": 0+1+2+None} ], 
      "total":10, "passed": 10, , "failed": 0, , "error": 0, "skipped": 0} 
"""
REPORT_DATA = {}

REPORT_DATA["suite"] = []

msg = []

def test(iscontinue=True):
    def decorated(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            print(dir(kwargs))
            __runwell = True
            result = None
            ret_assert = 0

            try:
                result = func(*args, **kwargs)
            except Exception as e:
                msg.append(traceback.format_exc())
                __runwell =False
                __run_msg = e
                pass
            finally:
                    
                if kwargs["aaa"] :
                    pass

                print("{}<Func> execute: {}{}".format(
                                                    func.__name__, 
                                                    result if __runwell else False, 
                                                    ".\t Exception happend: {}".format(__run_msg) if not __runwell else "" ))
                if not iscontinue: exit(0)
            return result
        return wrapper
    return decorated


def assertTrue(actual):
    return boolean(actual)

def assertEqual(actual,excp):
    return actual == excp


#coding=utf-8
from Crypto import Random
from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
from Crypto.PublicKey import RSA
import base64

# 伪随机数生成器
random_generator = Random.new().read
# rsa算法生成实例
rsa = RSA.generate(1024, random_generator)
#生成私钥
private_pem = rsa.exportKey()
print(private_pem)

#master-private.pem文件中写入私钥
# with open('master-private.pem', 'w') as f:
#     f.write(private_pem)
fout = open('master-private.pem', 'w', encoding='utf8')
fout.write(private_pem)
fout.close()

#生成公钥
public_pem = rsa.publickey().exportKey()
#master-public.pem公钥写入文件中
# with open('master-public.pem', 'w') as f:
#     f.write(public_pem)
fout2 = open('master-public.pem', 'w', encoding='utf8')
fout2.write(private_pem)
fout2.close()


if __name__=='__main__':
    message = 'hello world !'
    #将明文加密成密文
    with open('master-public.pem') as f:
        key = f.read()
        rsakey = RSA.importKey(key)
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        cipher_text = base64.b64encode(cipher.encrypt(message))
        print('hello world!对应的密文是：', cipher_text)

    #将密文解密成明文
    with open('master-private.pem') as f:
        key = f.read()
        rsakey = RSA.importKey(key)
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        text = cipher.decrypt(base64.b64decode(cipher_text), 'azx')
        print('解密后原文是:', text)




# -*- coding: utf-8 -*-

from luckdog.net.emnu import HeaderEmnu ,ContentTypeEmnu
from luckdog.net.http import HEADER, COOKIES
from luckdog.net.http import browser
from luckdog.utils.tools import util_json

def box(app,env):
    # browser2 = WBrowser()
    cookies = COOKIES()
    cookies.init("csrftoken=5u0dWiHHwu9l61SUpwt6yAr7KIjRi7kXp58Tds53eQQuLNGLhY3ng7bdpPwsfzGs; sessionid=clthf2aafzvq1kc3rt16tgkv1hby32ek; _ga=GA1.2.448745483.1585635101; ymmoa_passport=U3KGzFNNCjJj9D8NEBecitKiXD5PBtXgStZ9T3-OUaTZt25MQ6rIV2mUq3oCDStfimhj3QmDXGWGf_w6VPDWz1JPTXFgmG2phbmYaXC1T6gF85wgoAn9aA7jYHJRXRn0fcoinmsO-XFxO4CihcshkuXw8K39yv3ugMhGQF3rM8c; ymmoa_user={%22name%22:%22%E8%AF%B7%E4%B8%8D%E8%A6%81%E4%BD%BF%E7%94%A8%E6%AD%A4%20Cookie%22%2C%22avatarUrl%22:%22%22%2C%22departmentName%22:%22%E8%AF%B7%E4%B8%8D%E8%A6%81%E4%BD%BF%E7%94%A8%E6%AD%A4%20Cookie%22%2C%22id%22:9999999%2C%22jobNumber%22:%22Y9999999%22}; qa_passport=KswysbzLZmN6oXGCCNO6NT0b8RieqRZagaqbQTxpCKDWxXkf_Nh0q6klg_iv93f2gLBGEeeYRneU0huh9nrflGBbkyYcmb58rI30XsLEpGA5e-1Ye4Ti5OtzDNyCMt7ZE-WiXip9NaNg4Wj8tz5-EyewbfEi768VuVmtEH_6ubI; _gid=GA1.2.1085347497.1587352093; dev_passport=GWLtPheFKjNPOPSsf08CUZXGbza3zJ5KOaW-DcoFBGC2Sm_eWxHxDGzLxP7zBCdYJ8V47Ca6AXUBnDVd0XEfwq7mKHJismw4qtvYBWm6r3MIcwMiEXHQFVgIFCzxyfljI2JEPFlnupOx62v-yRI9e0i1IWtoubhkMuxMIxpylZM; _ssoSeed=1587370132954")
 
    header = HEADER()
    header.add("Host","docker-beidou.amh-group.com")
    header.add(HeaderEmnu.COOKIES,cookies.cookie())
    header.add(HeaderEmnu.ACCEPT,"*/*")

    browser2 = browser
    browser2.method("get")
    url = "https://docker-beidou.amh-group.com/cloud/api/container/"+app+"."+env+"/"
    browser2.url(url)
    browser2.header(header.get_headers())
    # print(header.get_headers())
    browser2.visit()
    
    print("*"*100)
    Response2 = browser2.visit() 
    # print(Response2)
    # print(Response2.text)
     
    src_dict = util_json.json_loads(Response2.text)
    keypath="container->ip@[0]"
    keypath="container->ip@[*]"
    dist = util_json.get_element_by_keypath(keypath, src_dict)
    print(dist)
    print(",".join(dist))

# box()



def getname(name):
    # browser2 = WBrowser()
    cookies = COOKIES()
    cookies.init("csrftoken=5u0dWiHHwu9l61SUpwt6yAr7KIjRi7kXp58Tds53eQQuLNGLhY3ng7bdpPwsfzGs; sessionid=clthf2aafzvq1kc3rt16tgkv1hby32ek; _ga=GA1.2.448745483.1585635101; ymmoa_passport=U3KGzFNNCjJj9D8NEBecitKiXD5PBtXgStZ9T3-OUaTZt25MQ6rIV2mUq3oCDStfimhj3QmDXGWGf_w6VPDWz1JPTXFgmG2phbmYaXC1T6gF85wgoAn9aA7jYHJRXRn0fcoinmsO-XFxO4CihcshkuXw8K39yv3ugMhGQF3rM8c; ymmoa_user={%22name%22:%22%E8%AF%B7%E4%B8%8D%E8%A6%81%E4%BD%BF%E7%94%A8%E6%AD%A4%20Cookie%22%2C%22avatarUrl%22:%22%22%2C%22departmentName%22:%22%E8%AF%B7%E4%B8%8D%E8%A6%81%E4%BD%BF%E7%94%A8%E6%AD%A4%20Cookie%22%2C%22id%22:9999999%2C%22jobNumber%22:%22Y9999999%22}; qa_passport=KswysbzLZmN6oXGCCNO6NT0b8RieqRZagaqbQTxpCKDWxXkf_Nh0q6klg_iv93f2gLBGEeeYRneU0huh9nrflGBbkyYcmb58rI30XsLEpGA5e-1Ye4Ti5OtzDNyCMt7ZE-WiXip9NaNg4Wj8tz5-EyewbfEi768VuVmtEH_6ubI; _gid=GA1.2.1085347497.1587352093; dev_passport=GWLtPheFKjNPOPSsf08CUZXGbza3zJ5KOaW-DcoFBGC2Sm_eWxHxDGzLxP7zBCdYJ8V47Ca6AXUBnDVd0XEfwq7mKHJismw4qtvYBWm6r3MIcwMiEXHQFVgIFCzxyfljI2JEPFlnupOx62v-yRI9e0i1IWtoubhkMuxMIxpylZM; _ssoSeed=1587370132954")
 
    header = HEADER()
    header.add("Host","docker-beidou.amh-group.com")
    header.add(HeaderEmnu.COOKIES,cookies.cookie())
    header.add(HeaderEmnu.ACCEPT,"*/*")

    browser2 = browser
    browser2.method("get")
    browser2.url("https://docker-beidou.amh-group.com/deploy/api/project/?ns=com.ymm&query=40&page=1&search="+name+"")
    browser2.header(header.get_headers())
    # print(header.get_headers())
    browser2.visit()
    
    print("*"*100)
    Response2 = browser2.visit() 
    # print(Response2)
    # print(Response2.text)
     
    src_dict = util_json.json_loads(Response2.text)
    keypath="container->ip@[0]"
    keypath="results->project@[0]->ns"
    dist = util_json.get_element_by_keypath(keypath, src_dict)
    print(dist)
    return dist
# qa zh 
box(getname("truck-iov-app"),"qa")


# -*- coding: UTF-8 -*-
import base64

import Crypto
from Crypto import Random
from Crypto.Cipher import PKCS1_v1_5 as PKCS1_v1_5_cipper
from Crypto.Hash import SHA
from Crypto.PublicKey import RSA
from Crypto.Signature import PKCS1_v1_5


# 使用 rsa库进行RSA签名和加解密
class RsaUtil(object):
    PUBLIC_KEY_PATH = 'master-private.pem'  # 公钥
    PRIVATE_KEY_PATH = 'master-public.pem'  # 私钥
    # PUBLIC_KEY_PATH = None # 公钥
    # PRIVATE_KEY_PATH = None  # 私钥

    PUBLIC_KEY_PATH_STR = None
    PRIVATE_KEY_PATH_STR = None

    # 初始化key
    def __init__(self,
                 pub_key=None,
                 pri_key=None,
                 company_pub_file=None,
                 company_pri_file=None):
        if company_pub_file:
            self.company_public_key = RSA.importKey(
                open(company_pub_file).read())
        if company_pri_file:
            self.company_private_key = RSA.importKey(
                open(company_pri_file).read())
        if pub_key:
            self.company_public_key = RSA.importKey(pub_key)
        if pri_key:
            self.company_private_key = RSA.importKey(pri_key)
        pass

    def gren(self):
        gene_bit_num = 1024
        # gene_pkcs_mod = 1 | 8
        gene_pkcs_mod = 1
        gene_passphrase = None
        # 伪随机数生成器
        random_generator = Random.new().read
        # rsa算法生成实例
        rsa_key = RSA.generate(2048, random_generator)
        # master的秘钥对的生成
        private_pem = rsa_key.exportKey(
            passphrase=gene_passphrase, pkcs=gene_pkcs_mod)
        # print(private_pem)
        with open('master-private.pem', 'wb') as f:
            f.write(private_pem)

        public_pem = rsa_key.publickey().exportKey()
        print(public_pem)
        with open('master-public.pem', 'wb') as f:
            f.write(public_pem)

        public_pem = rsa_key.publickey().exportKey()
        pass

    def load_rsa_key(self, pub=PUBLIC_KEY_PATH, pri=PRIVATE_KEY_PATH):
        print(open(pub).read())
        print(pub, pri)
        if pub:
            self.company_public_key = RSA.importKey(open(pub).read())
            print(self.company_public_key.n)
        if pri:
            self.company_private_key = RSA.importKey(open(pri).read())
            print(self.company_private_key.n)
        pass

    def get_max_length(self, rsa_key, encrypt=True):
        """加密内容过长时 需要分段加密 换算每一段的长度.
            :param rsa_key: 钥匙.
            :param encrypt: 是否是加密.
        """
        blocksize = Crypto.Util.number.size(rsa_key.n) / 8
        reserve_size = 11  # 预留位为11
        if not encrypt:  # 解密时不需要考虑预留位
            reserve_size = 0
        maxlength = blocksize - reserve_size
        return maxlength

    # 加密 支付方公钥
    def encrypt_by_public_key(self, encrypt_message):
        """使用公钥加密.
            :param encrypt_message: 需要加密的内容.
            加密之后需要对接过进行base64转码
        """
        encrypt_result = b''
        max_length = int(self.get_max_length(self.company_public_key))
        cipher = PKCS1_v1_5_cipper.new(self.company_public_key)
        while encrypt_message:
            input_data = encrypt_message[:max_length]
            encrypt_message = encrypt_message[max_length:]
            out_data = cipher.encrypt(input_data.encode(encoding='utf-8'))
            encrypt_result += out_data
        encrypt_result = base64.b64encode(encrypt_result)
        return encrypt_result

    # 加密 支付方私钥
    def encrypt_by_private_key(self, encrypt_message):
        """使用私钥加密.
            :param encrypt_message: 需要加密的内容.
            加密之后需要对接过进行base64转码
        """
        encrypt_result = b""
        max_length = int(self.get_max_length(self.company_private_key))
        cipher = PKCS1_v1_5_cipper.new(self.company_public_key)
        while encrypt_message:
            input_data = encrypt_message[:max_length]
            encrypt_message = encrypt_message[max_length:]
            out_data = cipher.encrypt(input_data.encode(
                encoding='utf-8').strip() + b"\n")
            encrypt_result += out_data
        encrypt_result = base64.b64encode(encrypt_result)
        return encrypt_result

    def decrypt_by_public_key(self, decrypt_message):
        """使用公钥解密.
            :param decrypt_message: 需要解密的内容.
            解密之后的内容直接是字符串，不需要在进行转义
        """
        decrypt_result = b""
        max_length = self.get_max_length(self.company_public_key, False)
        decrypt_message = base64.b64decode(decrypt_message)
        cipher = PKCS1_v1_5_cipper.new(self.company_public_key)
        while decrypt_message:
            input_data = decrypt_message[:max_length]
            decrypt_message = decrypt_message[max_length:]
            out_data = cipher.decrypt(input_data.encode(encoding='utf-8'), '')
            decrypt_result += out_data
        return decrypt_result

    def decrypt_by_private_key(self, decrypt_message):
        """使用私钥解密.
            :param decrypt_message: 需要解密的内容.
            解密之后的内容直接是字符串，不需要在进行转义
        """
        decrypt_result = b""
        max_length = int(self.get_max_length(self.company_private_key, False))
        decrypt_message = base64.b64decode(decrypt_message)
        cipher = PKCS1_v1_5_cipper.new(self.company_private_key)
        while decrypt_message:
            input_data = decrypt_message[:max_length]
            decrypt_message = decrypt_message[max_length:]
            out_data = cipher.decrypt(input_data, '')
            decrypt_result += str(out_data).encode(
                encoding='utf-8').strip() + b"\n"
        return decrypt_result

    # 签名 商户私钥 base64转码
    def sign_by_private_key(self, message):
        """私钥签名.
            :param message: 需要签名的内容.
            签名之后，需要转义后输出
        """
        cipher = PKCS1_v1_5.new(
            self.company_private_key)  # 用公钥签名，会报错 raise TypeError("No private key") 如下
        # if not self.has_private():
        #   raise TypeError("No private key")
        hs = SHA.new(message)
        signature = cipher.sign(hs)
        return base64.b64encode(signature)

    def verify_by_public_key(self, message, signature):
        """公钥验签.
            :param message: 验签的内容.
            :param signature: 对验签内容签名的值（签名之后，会进行b64encode转码，所以验签前也需转码）.
        """
        signature = base64.b64decode(signature)
        cipher = PKCS1_v1_5.new(self.company_public_key)
        hs = SHA.new(message)

        # digest = hashlib.sha1(message).digest()  # 内容摘要的生成方法有很多种，只要签名和解签用的是一样的就可以

        return cipher.verify(hs, signature)


pri_key = "MIICdwIBADANBgkqhkiG9w0BAQEFAASCAmEwggJdAgEAAoGBAN8Fv+ZPU+rxX2Qr3Q+no4olyDTxi3Ke51KYg4GkKmkrRQLqv5NbiC+Tg6DjE35xXNSR6VHvak8nt9a0lBRvi2inSK1OuAcjWspkuu5dmrUbgL5o4G036VvO+6jQlkKGV7ZLA5RcqsJiFVyRwWn5R3EspUVtuVGxOvxLcgv5+qwLAgMBAAECgYByXxd3e80UWm5KB7iZU6YprZCLnieeQ2Fr2SzvqgnZ30fH5C0U28buZx8Evg78NBSgKqfVzgrdxwefQwIBrOZ3cnspRtui4ahO6rXFmSCVAKhK7ibRG9Rhk1B+4SPu/ONZfr7/4eAc/5IyhTOpl6FiCO3wWttjB7q8qinY5NvigQJBAP1ggg1sKLqSO50BEe3sbhsvUfuuF79qRz3Cj5z4CIqm9oYIo5JlYr9A77WH22uvz9LE+aYiDYbGO50d1QmD90sCQQDhVMwE/E2y/KNx6kmkXcHJG5UBrzpbWZoBG9UZykwqlAHYpMHJWXAPi7xFqml4pU4rxUa9HpVRCbkcRNnFM2ZBAkAK/86FgKV/++sklLBPkMzy1yoK7/LN93IiRzjuyoGsazUWeneHWmlf/hSp37zxvs8Zyj1ALghCSoa5+lqOMDFjAkEAirjkvbECuM2WZjxByCI8em4zpwzU1YZtLH+RC0ai65ehJ1oPP8GDHt79Mrp+IltKq+HQ8f9RF8nvn3q3wxMowQJBALPY4LsnCUwnavEqlet6CvjuTmJFjq/nuSZwz1UiP9UVa8/EYSGcuUi5OjeN5h+wt9Y7y6qYLQScOQ0rT3aih0o="
# pub_key = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCylvPMI6QHoNmAOt0Pb+ONACaobN6LV65F9NnzjGugUFd1nwc4QJyfvn1sWYLvZi1zBw5Lbx1xDaBPazaz73JGu8ugyhIMr4V/dY7b4GKtMfwMMgGoEChigYlTRXeWR1suzIMxyMLsp8LUqyjfY6ebJa2L9niun0t7P4E7MaLTIQIDAQAB"
# data = "qACiIm0zLNB33dgJPHwP6E/v408h2mT6B90palMghxYfKFzIdG8Ws7C/lUeEr5h0rqYbzxBK2fLIMxYeuPGX69EVwD7wpZfnmgqwYi+aFbKBNpRVq1fqTkj8gF5sdpBNmUgOmC4pfqWNgBO2grHIxLGSMpBuuPLbrcJIm6UqYccrssRmXF5mqkqJvt072kgKF5VEUI9NrF4BLzX3Gz/Fb11OX7jnC89U4S7xPrafTzyP0nr+2dwwEh22fYH3Jfyi7k2NjTNbnS6QfzktI4s0B/oLoW6wbNnVlSSwKraX8f1IKPKFe8IdcLBjV2CeIrxq8cfqmjf7ATcTndoAhLt+f5E8Loqy59j85jsbWgk+hPir/kYpHxhnl7ZgGEiijmMnqg2/hWQ717w82cSLKBLeOtJ3rucxUNlhKcmZMf9RrS8hC7ajwPPP5cDmVZNf45Y+OH7JUTNan22F+QQzI7Szavclpw6ffHlgFsrZ4YPs1k2CFsEEsrlGHCvvEGeduwt7"
# key = base64.b64decode(pri_key)
#
# print(key)
# decrypt_result = rsaUtil.decrypt_by_private_key(base64.b64decode(data))
# print("解密结果：>>> ")
# print(decrypt_result)
rsaUtil = RsaUtil()
# rsaUtil.gren()
rsaUtil.load_rsa_key()

message = 'hellworldhellworldhellworldhell'
print("明文内容：>>> ")
print(message)
encrypy_result = rsaUtil.encrypt_by_public_key(message)
print("加密结果：>>> ")
print(encrypy_result)
decrypt_result = rsaUtil.decrypt_by_private_key(encrypy_result)
print("解密结果：>>> ")
print(decrypt_result)
decrypt_result2 = rsaUtil.decrypt_by_public_key(encrypy_result)
print("解密结果2：>>> ")
print(decrypt_result2)
# sign = rsaUtil.sign_by_private_key(bytearray(message.encode(encoding='utf-8')))
# print("签名结果：>>> ")
# print(sign)
# print("验签结果：>>> ")
# print(rsaUtil.verify_by_public_key(bytearray(message.encode(encoding='utf-8')), sign))



# -*- coding: utf-8 -*-

from test.suite import println,test

@test()
def add(a,b,expected=2):
    c = a + b 
    return c == expected

add(1,1,expected=2)  
add(1,"-1",expected=0)   
add(1,3,expected=4)  



#coding=utf-8
from Crypto import Random
from Crypto.Cipher import PKCS1_v1_5 as Cipher_pkcs1_v1_5
from Crypto.PublicKey import RSA
import base64

# 伪随机数生成器
random_generator = Random.new().read
# rsa算法生成实例
rsa = RSA.generate(1024, random_generator)
#生成私钥
private_pem = rsa.exportKey()

#master-private.pem文件中写入私钥
with open('master-private.pem', 'w') as f:
    f.write(private_pem)
#生成公钥
public_pem = rsa.publickey().exportKey()
#master-public.pem公钥写入文件中
with open('master-public.pem', 'w') as f:
    f.write(public_pem)
if __name__=='__main__':
    message = 'hello world !'
    #将明文加密成密文
    with open('master-public.pem') as f:
        key = f.read()
        rsakey = RSA.importKey(key)
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        cipher_text = base64.b64encode(cipher.encrypt(message))
        print 'hello world!对应的密文是：',cipher_text
    #将密文解密成明文
    with open('master-private.pem') as f:
        key = f.read()
        rsakey = RSA.importKey(key)
        cipher = Cipher_pkcs1_v1_5.new(rsakey)
        text = cipher.decrypt(base64.b64decode(cipher_text), 'azx')
        print '解密后原文是:',text



#coding=utf-8
from Crypto.PublicKey import RSA as rsa
from Crypto.Cipher import PKCS1_v1_5
import base64
class myencry(object):
    #构造方法传入公钥
    def __init__(self,pub_key_str=None):
        self.pub_key_str = """-----BEGIN RSA PUBLIC KEY-----
%s
-----END RSA PUBLIC KEY-----""" %pub_key_str
    #设置公钥
    def set_pk(self,pub_key_str):
        self.pub_key_str="""-----BEGIN RSA PUBLIC KEY-----
%s
-----END RSA PUBLIC KEY-----""" %pub_key_str
    #获取公钥
    def get_pk(self):
        return self.pub_key_str
    #获取加密对象
    def get_pubobj(self):
        pub_key_str=self.get_pk()
        pubobj = rsa.importKey(pub_key_str)
        pubobj = PKCS1_v1_5.new(pubobj)
        return pubobj
    #对用户名进行加密
    def get_encry_str(self,mingwen):
        encry_name = self.get_pubobj().encrypt(mingwen)
        miwen = base64.b64encode(encry_name)
        return miwen
if __name__=='__main__':
    pk='MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDgDq5fGYiRqDQyfDYiFuBVUHukaK9zQ/6EPzG0O8bf+sEVuuiiWDSrjMaM28GNZWuxQRu1JOXkq3pFgULvWdqDUr6dl3ucmW4O0xpTMOQaz0iwaUIJnWhg0blgmj+eA+ZHj51rdVBKfuOCOWE4QpJc5igtnOrGHEFPpi/Lg+c5hwIDAQAB'
    en=myencry(pk)
    # en.set_pk(pk)
    print en.get_encry_str('596579936@qq.com')
    print en.get_encry_str('bAOBAO521')

#coding=utf-8
from Crypto.PublicKey import RSA as rsa
from Crypto.Cipher import PKCS1_v1_5
import base64
import random
class mydecry(object):
    #构造方法传入私钥
    def __init__(self,private_key):
        self.private_key="""-----BEGIN RSA PRIVATE KEY-----
%s
-----END RSA PRIVATE KEY-----""" %private_key
        self.pk=private_key
    #获取私钥
    def get_key(self):
        return self.private_key
    def set_key(self,private_key):
        self.private_key="""-----BEGIN RSA PRIVATE KEY-----
%s
-----END RSA PRIVATE KEY-----""" %private_key
        self.pk=private_key
    #获取解密对象
    def get_cipher(self):
        pri_key_str=self.get_key()
        rsakey = rsa.importKey(pri_key_str)
        cipher = PKCS1_v1_5.new(rsakey)
        return cipher
    #获取随机数
    def get_random(self):
        index=random.random()
        return str(index)
    #获取解密后的明文
    def get_decry_str(self,miwen):
        cipher=self.get_cipher()
        mingwen = cipher.decrypt(base64.b64decode(miwen), self.get_random())
        return mingwen
if __name__=="__main__":
    from myEncry import myencry
    private_key='MIICdgIBADANBgkqhkiG9w0BAQEFAASCAmAwggJcAgEAAoGBAJF4ZQGUjeueZIaY5+HgEAr7leBvP8/ftemF+eaNzl5PRF7rf3wIeoC7x1QzOPBS3VwfNBrKjwGsmCeFrIXoFZrabLzeaSJq1L58KzwIXrTIPqimuCnP5+EXIOKwUhS74ie1CWttz01nEvoHGqGo5EC7K7UpX5hhhE+/UJSaNbg9AgMBAAECgYBBRYIcyWk8lZ+JfUZeZUkNhIFlaMV7ImffVkwhFPPKAUsuRAC5yJwe8yKnNyyPOL82PJIGi2jLWYQUB7i3hMFcQpDxmsfDqJk3zEQHNYhDGHuU57il7Cunn567C1HNUbxIHAuLwTB+fYIpE5TGipqitkbZrLyvk8UxEe5DqATzgQJBAM9jarYTemoIiU2sVO7Y6oDOGGLqTy8tdEG57ePZtR90/bSBXwcQjoZ+MuHPwG3ZMUd4cklLl3yiAS+hRJgkfTECQQCzkYLyXV2eT6SegT2NGqtv3PR0yUuadrs54V6/KRgAfkflBj+DzXYHJEuLV5JYTTHiP8WRp2xV/8/ZQPrhlvjNAkBn+wW28r8uyMbm3d/bvYCeQjcx6R74nYarqahf1Hkeo47M4QyfQyrivgWO+JYXvY0as4ZBv5fdknCby/TTf4ARAkEAmeA3tjkL4H2fM7TMaf5QqqtNUEau4s6b4h2ec3FjgAi20ytngiqu2a/gjKeeYMzF0nuTch1mWMu98Q4d7vLQgQJAYTTzuYRcZvCAM7axHr6r3GdIPwNzEunDKe1X1TKc2/GNC1ws43QYhblUSaoJqvJTnsClVT+SF0hPOzvKJNCLyg=='
    public_key='MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCReGUBlI3rnmSGmOfh4BAK+5Xgbz/P37Xphfnmjc5eT0Re6398CHqAu8dUMzjwUt1cHzQayo8BrJgnhayF6BWa2my83mkiatS+fCs8CF60yD6oprgpz+fhFyDisFIUu+IntQlrbc9NZxL6BxqhqORAuyu1KV+YYYRPv1CUmjW4PQIDAQAB'
    myencry=myencry(public_key)
    miwen=myencry.get_encry_str('hello')
    print miwen
    mydecry=mydecry(private_key)
    mingwen=mydecry.get_decry_str(miwen)
    print mingwen


# -*-coding=utf-8 -*-
__author__  = "9304.com"
__date__    = "2020-04-20"

from setuptools import setup, find_packages
import sys
import os

# 如果是Windows，显示“nt”，如果是Linux，则“posix”
from luckdog.__version__ import __VERSION__

setup(
    name="luckdog",
    version = __VERSION__,
    author="goblinintree",
    author_email="goblinintree@126.com",
    description="a light-minded faceman,like postman.",
    long_description=open("README.md",encoding="UTF-8").read(),
    long_description_content_type="text/markdown",
    platforms=["all"],
    license="MIT",
    keywords = ['postman', 'faceman', 'test'],
    url="https://pypi.org/project/luckdog/#description",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Environment :: Web Environment",
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft',
        'Programming Language :: Python :: 3.7',
    ],
    zip_safe=True,
    install_requires=[
        "requests",
    ],
)


# -*- coding: utf-8 -*-

import base64
import rsa

publicKey = "MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCylvPMI6QHoNmAOt0Pb+ONACaobN6LV65F9NnzjGugUFd1nwc4QJyfvn1sWYLvZi1zBw5Lbx1xDaBPazaz73JGu8ugyhIMr4V/dY7b4GKtMfwMMgGoEChigYlTRXeWR1suzIMxyMLsp8LUqyjfY6ebJa2L9niun0t7P4E7MaLTIQIDAQAB"
privateKey = "MIICdgIBADANBgkqhkiG9w0BAQEFAASCAmAwggJcAgEAAoGBALKW88wjpAeg2YA63Q9v440AJqhs3otXrkX02fOMa6BQV3WfBzhAnJ++fWxZgu9mLXMHDktvHXENoE9rNrPvcka7y6DKEgyvhX91jtvgYq0x/AwyAagQKGKBiVNFd5ZHWy7MgzHIwuynwtSrKN9jp5slrYv2eK6fS3s/gTsxotMhAgMBAAECgYBlF8IF6p7tmoXEao28MVAT/uPjL02Cfy2td/7wOKqr4w6/DDhgBWMjogcJkFnn/mT32iSjWtDFsDrw+fXLQV3j7lDFO+i3ubGXpYPBg+8DzpzSksU8/AYT0+vbDAfkAePcMfDTBToqg/n87USc+7zMnKtboVzjkbBtveWOto3WqQJBANe9Kenrwm6r2u+H1YzZ3rqLbWQq1yhqvY0XLv1BlRVNCwJfSIZ5Y4qGvgyT05F4lKK1HfZO2KbO2zRUl9qn4PcCQQDT6v+H/MAutMiz70P+Gc3458lF/pC/h8PiMF823r0oHoV2cTgljv/N4z5Gkxk0suFnU6BiV5gtpj1uZYlZ5v6nAkAPcS/V2ZVCPLTgHlXvzgx+R8qdt99Muk81ESrA3/fe3XPjSJS1Y2z3lmt2FQK4z+u7tcEeR0iEsBvKpB92fDvDAkBsZT2DX2MmAM7QSshqhuR2NokbRlTfwyAM6FUric8TYFk/9jWT8Isj0uKd0swHyp/E7F+TLd7nKqstdr5EwATtAkEAy3VYpUOW5XoIsFQvd5oTcSC+L8sY2FyMyUooXmfXOAnw5hZp2fVG1bIsVMDbYfkH1cDec3DLuTHVKTYYWy3zNQ=="
content = "aWKmYUQ3whFj2KyRd5npX3zGH+EzcF8EYgHGl32ExwPRwsVUk0OG2DtJ3hTUTmzfJQwhdO/ec/GzF5q8AHZjWoDNlw/0yDQghDDAlMQ0V9SBYWnkXqoI0oyRas4KU/psPmimabB4u4NoLmVX5RV243/jpMjpaashLMOjTl8BaxQaPjW4+wKCH4pPJWfdpQ0WesUVNk1vq/vYtGfb326F4sIxiF26MfmnrnoCohvYU9SfRiZ/eP8hGBLlUH4lplhYQSJwvZP/Y0KVsHw0lHxa+T6nd+uy0uFt8i3/1mWTFqvsiOZgg7I/JRsLCVw3FxerKVKGg3oi9Dj2yYhzgpvFPE0QGiqbMsBO1WaQxw1ZocEUx7OboNtfdMyhZf+Jq316KbKe1XIKUCKWBbJpKxMefmDBRkyUGkNCb7uHAF0ANPISnyHFdK+428qUZL6hlH1cXkhDKw+noEr0/BpQe3YAngNQM0jZGXR9wewTU7L9zrf2Oun4i8P8zgSsj/hPYMfalLcP3NR0G0flVZzbftaMI7ZXh8nm20BAI/Gv0lBU8pW1kMnrHlm+gPt8Bjkfpocel+QOpVOicDeYx2sBAmBNx4ux2TvPSmFHePSqMAffzkPLICTGD3e/ckLovWeixIp5kcZNDWWj7O5/WPRsXu+AK6muyOHLzhaxD1NmknQ6FBxneSDC5X9b+VyMHkjDN+VVBwL+ZnnZcLWRR6hhi1W03hJkYRbmJSD0cQMVYIksZHJcR62P78jMqq4+TG73VMDKEEGnF/YaUoc2bgfYpz1KPQOFZ1ALXcm4mB/2agodKLikN5DRr5YuJtUlCmIF2WhobcYrvQDTqNjImb52pWv2Lg=="
private_key_pem ="""-----BEGIN RSA PRIVATE KEY-----
%s
-----END RSA PRIVATE KEY-----""" %base64.b64decode(privateKey)
public_key_pem ="""-----BEGIN RSA PUBLIC KEY-----
%s
-----END RSA PUBLIC KEY-----""" %publicKey

# import base64
# plaintext="明文"
# ciphertext = base64.b64encode(plaintext)
# plaintext = base64.b64decode(ciphertext)

# import rsa
# plaintext="明文"
# ciphertext = rsa.encrypt(plaintext, publicKey)
# plaintext = rsa.decrypt(ciphertext, privateKey)
(pubkey, privkey) = rsa.newkeys(1024)
pub = pubkey.save_pkcs1()
pubfile = open('public.pem','wb')
pubfile.write(pub)
pubfile.close()
pri = privkey.save_pkcs1()
prifile = open('private.pem','wb')
prifile.write(pri)
prifile.close()


# load公钥和密钥
message = 'lovesoo.org'
with open('public.pem') as publickfile:
  p = publickfile.read()
  pubkey = rsa.PublicKey.load_pkcs1(p)
with open('private.pem') as privatefile:
  p = privatefile.read()
  privkey = rsa.PrivateKey.load_pkcs1(p)
# 用公钥加密、再用私钥解密
crypto = rsa.encrypt(message, pubkey)
message = rsa.decrypt(crypto, privkey)
print(message)
# sign 用私钥签名认证、再用公钥验证签名
signature = rsa.sign(message, privkey, 'SHA-1')
rsa.verify('lovesoo.org', signature, pubkey)






class mydecry(object):
    #构造方法传入私钥
    def __init__(self,private_key_pem):
        self.private_key_pem = private_key_pem
        # private_key_pem_encode =  base64.b64decode(privateKey)
        self.pk = rsa.PrivateKey.load_pkcs1(private_key_pem)
        print(self.pk )

    def decry_str(self,miwen):
        bit_miwen = base64.b64decode(miwen)
        mingwen = rsa.decrypt(bit_miwen, self.pk)
        return mingwen